@@ -44,7 +44,9 @@ class NotebookItem(pytest.Item):
         source = Path(self.config.rootdir) / self.filename
         run = NotebookRun(
             source,
+            option.nbmake_timeout,
             verbose=bool(option.verbose),
+            kernel=option.nbmake_kernel,
         )
 
         res: NotebookResult = run.execute()
